PyXMake Developer Guide: PyXMake.VTL.stm_make.InDevelopmentTest Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Attributes | List of all members
PyXMake.VTL.stm_make.InDevelopmentTest Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.InDevelopmentTest:

## Public Attributes
| out
Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
| command
| out
| covout
| verbose

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseTest
def | initialize_options (self)
def | finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
def | run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
string | description = "Runs all unit tests using py.test."
list | user_options

## Detailed Description

    Runs all unit tests.

Definition at line 967 of file stm_make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/VTL/stm_make.py